@@ -4,9 +4,9 @@ __all__ = [
 
 __title__ = "vivarium_cluster_tools"
 __summary__ = "A set of tools for running simulation using vivarium on cluster."
-__uri__ = "https://stash.ihme.washington.edu/projects/CSTE/repos/vivarium_cluster_tools"
+__uri__ = "https://github.com/ihmeuw/vivarium_cluster_tools"
 
-__version__ = "1.0.8"
+__version__ = "1.2.0"
 
 __author__ = "The vivarium developers"
 __email__ = "vivarium.dev@gmail.com"
